@@ -1,7 +1,7 @@
 """
 Type annotations for emr-containers service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/literals/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_emr_containers/literals/)
 
 Usage::
 
@@ -273,6 +273,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
